# Table of Contents

- [objective-modeling-guidelines](<./objective-modeling-guidelines.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Objective Modeling Guidelines](<./Objective-Modeling-Guidelines.md>)
  - [Definition](<./Objective-Modeling-Guidelines/Definition.md>)
  - [Description](<./Objective-Modeling-Guidelines/Description.md>)
  - [Guidelines and Best Practices](<./Objective-Modeling-Guidelines/Guidelines-and-Best-Practices.md>)
  - [How to Model Relations Between Objectives and Other Fact Sheets](<./Objective-Modeling-Guidelines/How-to-Model-Relations-Between-Objectives-and-Other-Fact-Sheets.md>)
  - [Antipatterns](<./Objective-Modeling-Guidelines/Antipatterns.md>)
  - [Applicable Use Cases](<./Objective-Modeling-Guidelines/Applicable-Use-Cases.md>)
  - [Insights from Objective Fact Sheet](<./Objective-Modeling-Guidelines/Insights-from-Objective-Fact-Sheet.md>)
  - [Related Information](<./Objective-Modeling-Guidelines/Related-Information.md>)
